@@ -22,16 +22,19 @@ C       for solving system of equations using Fortran routines called
 C       by S function solve).
 C
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
-      DOUBLE PRECISION BETA(*),U(*),V(*),LOGLIK,C(nvi),wv(*),
-     &     deltab(nvi),vsq(nvi,nvi),penalt(*),wt(*)
-      DOUBLE PRECISION opts(*),prc(4)
-      DOUBLE PRECISION X(*),offset(*)
+      INTEGER maxit
+      DOUBLE PRECISION BETA(nvi),U(nvi),V(nvi*(nvi+1)/2),LOGLIK,
+     &     C(nvi), wv(2*nvi),
+     &     deltab(nvi),vsq(nvi,nvi),penalt(nvi,nvi),wt(NOBS)
+      DOUBLE PRECISION opts(12),prc(4)
+      DOUBLE PRECISION X(NOBS,NX),offset(NOBS)
 C     Dimensions of X, penalt, wt not needed until inside LLOGIT
-      INTEGER IDX(*),R(*),ftable(501,*),numy(*),pivot(nvi)
+      INTEGER IDX(nxin), R(NOBS), ftable(501,nvi-nxin+1),
+     &     numy(nvi-nxin+1), pivot(nvi)
       LOGICAL DVRG,ofpres,piter,normwt
       eps   = opts(1)
       dlike = opts(2)
-      maxit = opts(3)
+      maxit = INT(opts(3))
       piter = opts(4) .EQ. 1d0
       ofpres= opts(5) .EQ. 1d0
       normwt= opts(12) .EQ. 1d0
@@ -94,8 +97,9 @@ C     Compute V inverse * U by solving system of equations
             RETURN
          ENDIF
 C     UPDATE BETA ESTIMATES
-         DO 630 I=1,NVI
- 630        BETA(I)=BETA(I) + deltab(I)
+         DO I=1,NVI
+           BETA(I)=BETA(I) + deltab(I)
+         END DO
 C     call dblepr('v',1,v,nvi*(nvi+1)/2)
 C     call dblepr('deltab',6,deltab,nvi)
 C     call dblepr('beta',4,beta,nvi)
@@ -125,9 +129,19 @@ C     NOTE: V IS NOT INVERTED.
          IF(dvrg)opts(6)=1d0
          RETURN
          END
-      SUBROUTINE LLOGIT(BETA,IDX,X,R,offset,U,V,C,LOGLIK,
-     &  NOBS,NMAX,nxm,ofpres,NVI,KINT,DVRG,ftable,calcc,penalt,
-     &  wt,normwt)
+
+C Statement Functions have been deprecated
+C This is now a top level function.
+      FUNCTION lprob(bb)
+        implicit none
+        double precision lprob, bb
+        lprob=1D0/(1D0 + DEXP(-DMIN1(DMAX1(bb,-30D0),30D0)))
+        RETURN
+      END
+         
+      SUBROUTINE LLOGIT(BETA, IDX, X, R, offset, U, V, C,
+     & LOGLIK, NOBS, NMAX, nxm, ofpres, NVI, KINT, DVRG,
+     & ftable, calcc, penalt, wt, normwt)
 C
 C     ROUTINE TO CALCULATE LOGISTIC LOG LIKELIHOOD AND ITS DERIVATIVES AT BETA
 C     FOR VARIABLES IDX(1),IDX(2),...,IDX(NVI-KINT).
@@ -147,12 +161,20 @@ C     Penalties for intercept terms assumed to be zero
 C     Log likelihood is penalized by 0.5 times beta'*penalt*beta
 C
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
-      DOUBLE PRECISION BETA(*),U(*),V(*),C(*),LOGLIK,penalt(nvi,nvi),
-     & wt(nmax)
-      DOUBLE PRECISION X(NMAX,NXm),offset(nmax)
-      INTEGER IDX(*),R(NMAX),ftable(501,*)
+      DOUBLE PRECISION BETA(nvi),U(nvi),V(nvi*(nvi+1)/2),
+     & C(nvi), LOGLIK, penalt(nvi,nvi), wt(nmax)
+      DOUBLE PRECISION X(NMAX,nxm),offset(nmax)
+      DOUBLE PRECISION lprob
+      INTEGER IDX(nxm),R(NMAX),ftable(501,KINT+1)
       LOGICAL DVRG,ofpres,calcc,normwt
-      PROB(BB)=1D0/(1D0 + DEXP(-DMIN1(DMAX1(BB,-30D0),30D0)))
+C Default initializations
+      VIY = 0
+      VIY1 = 0
+      PIY = 0
+      PIY1 = 0
+      CPIY = 0
+      CPIY1 = 0
+      MID = 0
       NV=NVI
       BX=0
       KINT1=KINT + 1
@@ -194,9 +216,9 @@ C
 C       Get middle category for predicted prob.
 C
       IF(calcc) THEN
-         mid=kint1/2
-         DO i=1,501
-            DO j=1,kint1
+         mid=kint1 / 2
+         DO i=1, 501
+            DO j=1, kint1
                ftable(i,j)=0
             ENDDO
          ENDDO
@@ -218,10 +240,10 @@ C
                ENDIF
                bx=bx + beta(i)*c(i)
             ENDDO
-            cpiy=PROB(bx + off)
+            cpiy=lprob(bx + off)
             IF(calcc) THEN
-               ipp=500d0*cpiy + 1d0
-               if(.NOT. normwt) incobs=w + .5D0
+               ipp=INT(500d0*cpiy + 1d0)
+               if(.NOT. normwt) incobs=INT(w + .5D0)
                ftable(ipp,iy + 1)=ftable(ipp,iy + 1) + incobs
             ENDIF
             viy=cpiy*(1D0 - cpiy)
@@ -260,16 +282,16 @@ C     Add to first and second derivatives
          ENDIF
 C     COMPUTE EXCEEDENCE PROBABILITIES AND CHECK FOR DIVERGENCE
          IF(calcc) THEN
-            ipp=500d0*prob(bx + beta(mid) + off) + 1d0
-            if(.NOT. normwt)incobs=w + .5D0
+            ipp=INT(500d0*lprob(bx + beta(mid) + off) + 1d0)
+            if(.NOT. normwt)incobs=INT(w + .5D0)
             ftable(ipp,iy + 1)=ftable(ipp,iy + 1) + incobs
          ENDIF
          IF(iy.NE.0) THEN
-            CPIY=PROB(bx + beta(iy) + off)
+            CPIY=lprob(bx + beta(iy) + off)
             VIY=CPIY*(1D0 - CPIY)
             IF(IY .EQ. KINT)GO TO 78
          ENDIF
-         CPIY1=PROB(BX + BETA(IY + 1) + off)
+         CPIY1=lprob(BX + BETA(IY + 1) + off)
          VIY1=CPIY1*(1D0 - CPIY1)
          IF(CPIY1 .LT. 1D0)GO TO 80
          GO TO 74
@@ -331,8 +353,9 @@ C     0<IY<KINT
       END
       SUBROUTINE gcorr(ftable, kint, numy, nx, c, somer,
      &     gamma, taua)
-      INTEGER ftable(501,*),numy(*)
-      DOUBLE PRECISION fn,c,somer,gamma,taua,con,dis,tie,k,ic,nn
+      INTEGER ftable(501, kint + 1), numy(kint + 1)
+      DOUBLE PRECISION fn, c, somer, gamma, taua, con, dis, tie,
+     &   k, ic, nn
       kint1=kint + 1
       con=0d0
       dis=0d0
